@@ -42,6 +42,8 @@ class Pore():
         self._block = block
         self._matrix = matrix
 
+        self._num_in_ex = 0
+
         self._mol_dict = {"block": {}, "in": {}, "ex": {}}
 
 
@@ -81,7 +83,7 @@ class Pore():
             Maximal displacement distance
         accept : list, optional
             Acceptance criteria for allowed bond distances with partners
-        trials : integer
+        trials : integer, optional
             Allowed number of trials per atom
         """
         # Get connectivity matrix
@@ -161,16 +163,21 @@ class Pore():
         # Fill other information
         for si, data in self._sites.items():
             # Site type
+            is_in = False
+            is_ex = False
             if exterior:
                 for o in data["o"]:
                     if o in exterior:
-                        site_type = "ex"
-                        break
+                        is_ex = True
                     else:
-                        site_type = "in"
+                        is_in = True
             else:
-                site_type = "in"
-            data["type"] = site_type
+                is_in = True
+
+            data["type"] = "ex" if is_ex else "in"
+
+            if is_in and is_ex:
+                self._num_in_ex += 1
 
             # State
             data["state"] = True
@@ -202,7 +209,7 @@ class Pore():
         trials : integer, optional
             Number of trials picking a random site
         pos_list : list, optional
-            List of positions to find nearest available binding site for
+            List of positions (cartesian) to find nearest available binding site for
         site_type : string, optional
             Site type - interior **in**, exterior **ex**
         is_proxi : bool, optional
@@ -329,8 +336,8 @@ class Pore():
 
         # Create siloxane molecule
         mol = Molecule("siloxane", "SLX")
-        mol.add("O", [0, 0, 0], name="OM")
-        mol.add("O", 0, r=0.09, name="OM")
+        mol.add("O", [0, 0, 0], name="OM1")
+        mol.add("O", 0, r=0.09, name="OM1")
         mount = 0
         axis = [0, 1]
 
@@ -579,3 +586,14 @@ class Pore():
             Dictionary of all molecules with sorted sites
         """
         return self._mol_dict
+
+    def get_num_in_ex(self):
+        """Return the number of geminal si-binding sites that have one OH on the
+        interior surface and on on the exterior surface.
+
+        Returns
+        -------
+        num_in_ex : integer
+            Dictionary of all molecules with sorted sites
+        """
+        return self._num_in_ex
